isWritable property
bool
get
isWritable
Returns true if the stream is ready for writing More precise than !isClosed as it excludes closing state
Implementation
bool get isWritable;
Returns true if the stream is ready for writing More precise than !isClosed as it excludes closing state
bool get isWritable;