p2p/network/swarm/swarm_dial library
Classes
- AddrDialer
- AddrDialer is a helper for dialing multiple addresses in parallel
- CapabilityAwarePriorityRanker
- Priority ranker that considers local network capabilities
- DelayDialRanker
- DialRanker implementation that ranks addresses by delay
- DialBackoff
- DialBackoff implements exponential backoff for failed dials
- HappyEyeballsDialer
- Happy Eyeballs dialer with staggered connection attempts (RFC 8305)
- ScoredAddress
- Address with priority and timeout information for connection attempts