p2p/protocol/circuitv2/client/client library

Classes

CircuitListener
CircuitListener implements the Listener interface for circuit relay transport. It listens for incoming relayed connections from the CircuitV2Client.
CircuitV2Client
CircuitV2Client implements the Circuit Relay v2 protocol as a Transport. It allows peers to establish connections through relay servers when direct connections are not possible (e.g., due to NATs or firewalls).

Constants

maxCircuitMessageSize → const int

Typedefs

RelayPathFailedCallback = void Function(PeerId remotePeer, String reason)
Callback invoked when a relay path fails