Entry class

Entry for a connection in the identify service

Constructors

Entry()

Properties

hashCode int
The hash code for this object.
no setterinherited
identifySucceeded bool
Whether identify has completed successfully for this connection. When true, subsequent calls to identifyWait will return immediately without re-running the identify protocol.
getter/setter pair
identifyWaitCompleter Completer<void>?
Completer for the identify wait operation
getter/setter pair
pushSupport IdentifyPushSupport
Push support status for the peer
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence int
Sequence number of the last snapshot sent to this peer
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited