IdentifyStreamException class

Exception thrown when identify stream negotiation fails.

This occurs when:

  • Unable to open a stream to the peer
  • Multistream protocol negotiation fails
  • Stream is closed by remote during negotiation
Inheritance

Constructors

IdentifyStreamException({PeerId? peerId, required String message, Object? cause})

Properties

cause Object?
The underlying cause of the failure (if any).
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
A descriptive message about the failure.
finalinherited
peerId PeerId?
The peer ID for which identification failed (if known).
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited