HandshakeState class
Represents the immutable state of a Noise handshake
Constructors
- HandshakeState({required Uint8List chainKey, required Uint8List handshakeHash, required XXHandshakeState state, SecretKey? cipherKey, int cipherNonce = 0, SecretKey? sendKey, SecretKey? recvKey, Uint8List? remoteEphemeralKey, Uint8List? remoteStaticKey})
-
const
Properties
- chainKey → Uint8List
-
final
- cipherKey → SecretKey?
-
Current cipher key during handshake (updated by MixKey/DH operations).
null means "empty key" = encryption is identity (pass-through).
final
- cipherNonce → int
-
Cipher nonce, reset to 0 after each MixKey.
final
- handshakeHash → Uint8List
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- recvKey → SecretKey?
-
Final recv key (only set after Split at handshake completion).
final
- remoteEphemeralKey → Uint8List?
-
final
- remoteStaticKey → Uint8List?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendKey → SecretKey?
-
Final send key (only set after Split at handshake completion).
final
- state → XXHandshakeState
-
final
Methods
-
copyWith(
{Uint8List? chainKey, Uint8List? handshakeHash, XXHandshakeState? state, SecretKey? cipherKey, bool clearCipherKey = false, int? cipherNonce, SecretKey? sendKey, SecretKey? recvKey, Uint8List? remoteEphemeralKey, Uint8List? remoteStaticKey}) → HandshakeState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited