RelayMetricsObserver class abstract
Observer interface for Circuit Relay v2 client metrics
This optional callback interface allows external metrics collectors to observe relay events for monitoring and performance analysis.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onIncomingRelayConnection(
PeerId sourcePeer, PeerId relayPeer, DateTime timestamp, {String? sessionId}) → void - Called when an incoming relay connection is accepted (receiver side)
-
onRelayDialCompleted(
PeerId relayPeer, PeerId destPeer, DateTime startTime, DateTime completeTime, Duration duration, bool success, String? error, {String? sessionId}) → void - Called when a relay dial is completed
-
onRelayDialStarted(
PeerId relayPeer, PeerId destPeer, DateTime timestamp, {String? sessionId}) → void - Called when a relay dial is initiated
-
onReservationCompleted(
PeerId relayPeer, DateTime requestTime, DateTime completeTime, Duration duration, bool success, String? error, {String? sessionId}) → void - Called when a relay reservation is completed
-
onReservationRequested(
PeerId relayPeer, DateTime timestamp, {String? sessionId}) → void - Called when a relay reservation is requested
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited